@@ -7,6 +7,7 @@ use Catalyst qw( Unicode );
 
 __PACKAGE__->config({
     name => 'TestAppUnicode',
+    disable_component_resolution_regex_fallback => 1,
     'View::JSON' => {
         allow_callback => 1,
         callback_param => 'cb',
@@ -15,10 +16,4 @@ __PACKAGE__->config({
 
 __PACKAGE__->setup;
 
-sub foo : Global {
-    my ( $self, $c ) = @_;
-    $c->stash->{foo} = "\x{30c6}\x{30b9}\x{30c8}";
-    $c->forward('TestAppUnicode::View::JSON');
-}
-
 1;
